FlowActionBindingFingerprint class final

One deep-frozen installed action binding represented in a V1 contract.

Annotations
  • @immutable

Constructors

FlowActionBindingFingerprint({required String actionId, required String actionName, required int contractVersion, required FlowContentHash argsSchemaHash, required FlowContentHash resultSchemaHash, required int minClient, required bool idempotent})
Creates and validates an action-binding fingerprint.
factory

Properties

actionId String
Registry map key.
final
actionName String
Installed action name.
final
argsSchemaHash FlowContentHash
Canonical installed argument-schema hash.
final
contractVersion int
Installed action contract version.
final
hashCode int
The hash code for this object.
no setterinherited
idempotent bool
Whether the installed action is idempotent.
final
minClient int
Highest document action floor this binding supports.
final
resultSchemaHash FlowContentHash
Canonical installed result-schema hash.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited