FlowExperimentAccepted class final

The baseline and candidate are compatible from documents/capabilities alone.

Inheritance
Annotations
  • @immutable

Constructors

FlowExperimentAccepted()
Creates an accepted decision.
const

Properties

accepted bool
Whether the candidate can be assigned and rendered.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited