payloadIntegrityVerified property
Whether the enclosing surface payload passed its integrity checks.
Implementation
final bool payloadIntegrityVerified;
Whether the enclosing surface payload passed its integrity checks.
final bool payloadIntegrityVerified;