rfwIntegrityVerified property
Whether every referenced screen decoded under the installed RFW runtime.
Implementation
final bool rfwIntegrityVerified;
Whether every referenced screen decoded under the installed RFW runtime.
final bool rfwIntegrityVerified;