FlowExperimentDescriptor class final

The generated root-flow descriptor represented in a V1 client contract.

Annotations
  • @immutable

Constructors

FlowExperimentDescriptor({required String id, required int version, required int minClient})
Creates a descriptor. Its domains are checked by the enclosing contract.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable root flow identifier.
final
minClient int
Installed capability floor of the generated root reference.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
Exact generated root version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited