FlowExperimentEligibilityEvaluator class abstract final

Shared pure evaluator for typed and general V1 flow candidates.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

evaluate(FlowExperimentVerdictInput input) FlowExperimentVerdict
Evaluates input without IO and never throws to the caller.