FlowExperimentRejected class final

A fail-closed V1 eligibility decision.

Inheritance
Annotations
  • @immutable

Constructors

FlowExperimentRejected({required FlowExperimentRejectionReason reason, required String message})
Creates a typed rejection.
const

Properties

accepted bool
Whether the candidate can be assigned and rendered.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
message String
Diagnostic suitable for internal logs.
final
reason FlowExperimentRejectionReason
Stable rejection category.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited