FlowExperimentVerdict class sealed

Total V1 flow-experiment eligibility result.

Implementers

Properties

accepted bool
Whether the candidate can be assigned and rendered.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited