FlowExperimentVerdictInput class final
Complete pure input to the shared V1 eligibility predicate.
- Annotations
-
- @immutable
Constructors
-
FlowExperimentVerdictInput({required FlowExperimentClosure clientBaselineClosure, required FlowExperimentClosure candidateArmClosure, required InstalledCapability installedCapability, required List<
FlowActionBindingFingerprint> actionBindings, required List<String> installedSignals, required Surface surfaceType, required FlowDeliveryMode deliveryMode, required int flowGateRevision}) -
Creates a deep-frozen evaluator input.
factory
Properties
-
actionBindings
→ List<
FlowActionBindingFingerprint> -
Installed action mount fingerprints.
final
- candidateArmClosure → FlowExperimentClosure
-
Trusted-resolver candidate closure.
final
- clientBaselineClosure → FlowExperimentClosure
-
Exact client-bundled baseline closure.
final
- deliveryMode → FlowDeliveryMode
-
Delivery mode anchored by the mount.
final
- flowGateRevision → int
-
Evaluator revision included in verdict identity.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installedCapability → InstalledCapability
-
Installed renderer capability.
final
-
installedSignals
→ List<
String> -
Installed general-surface signal names.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surfaceType → Surface
-
Surface category anchored by the mount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited