AnalyticsEventSpec class final

The registry entry for a canonical event name.

Annotations
  • @immutable

Constructors

AnalyticsEventSpec({required String tier, Set<String> requiredProperties = const <String>{}})
Creates a spec. requiredProperties is copied into an unmodifiable set so the value type cannot be mutated through the constructor argument.

Properties

hashCode int
The hash code for this object.
no setteroverride
requiredProperties Set<String>
Property keys an emitter is expected to provide for this event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tier String
Sampling tier (see AnalyticsTier). Server-derived from this registry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override