FoldUsdValue class final

A successful conversion to usdMicros (signed micros of USD).

Inheritance
Annotations
  • @immutable

Constructors

FoldUsdValue(int usdMicros)
Wraps the converted usdMicros.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usdMicros int
The converted amount in signed micros of USD.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override