InstalledCapability class final
The built-in and custom library capabilities installed in a renderer.
- Annotations
-
- @immutable
Constructors
-
InstalledCapability({required int builtInCatalogVersion, required List<
InstalledLibrary> installedLibraries}) -
Creates an installed capability snapshot.
factory
-
InstalledCapability.fromJson(Map<
String, dynamic> json) -
Decodes an installed capability snapshot from its JSON wire form.
factory
Properties
- builtInCatalogVersion → int
-
The installed built-in catalog content version.
final
- contentHash → String
-
SHA-256 content hash for the canonical JSON wire form.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
-
installedLibraries
→ List<
InstalledLibrary> -
Installed custom libraries, sorted by namespace.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON wire form.
-
toString(
) → String -
A string representation of this object.
inherited
-
versionOf(
String namespace) → int? -
Returns the installed version for
namespace, ornullif the library is absent or unversioned.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override