FlowExperimentDocumentContract class final
One exact document in a V1 flow closure.
- Annotations
-
- @immutable
Constructors
-
FlowExperimentDocumentContract({required Surface surfaceType, required String flowId, required int version, required int schemaVersion, required int minClient, required FlowContentHash contentHash, required List<
LibraryRequirement> requiredLibraries, required FlowDocument flowDocument}) -
Creates and independently validates a document wrapper.
factory
Properties
- canonicalFlowDocumentBytes → Uint8List
-
FlowDocument JSON as nested in the V1 canonical contract.
no setter
- contentHash → FlowContentHash
-
Hash of the production canonical FlowDocument bytes.
final
- flowDocument → FlowDocument
-
A fresh document decoded through the production FlowDocument codec.
no setter
- flowId → String
-
Exact flow identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minClient → int
-
Document capability floor.
final
-
requiredLibraries
→ List<
LibraryRequirement> -
Custom libraries required by the surface payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
Supported flow schema version. V1 accepts exactly schema 1.
final
- surfaceType → Surface
-
Surface category of this closure node.
final
- version → int
-
Exact flow version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited